==> owlapi-parsers-3.4.2-sources.jar: org/coode/owlapi/owlxml/renderer/OWLXMLOntologyStorageException.java <==
/*
 * This file is part of the OWL API.
 *
 * The contents of this file are subject to the LGPL License, Version 3.0.
 *
 * Copyright (C) 2011, The University of Manchester
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0
 * in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 *
 * Copyright 2011, University of Manchester
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.coode.owlapi.owlxml.renderer;

import org.semanticweb.owlapi.model.OWLOntologyStorageException;


/**
 * Author: Matthew Horridge<br>
 * The University Of Manchester<br>
 * Bio-Health Informatics Group<br>
 * Date: 13-Apr-2007<br><br>
 */
@SuppressWarnings("javadoc")
public class OWLXMLOntologyStorageException extends OWLOntologyStorageException {


	private static final long serialVersionUID = 30402L;


    public OWLXMLOntologyStorageException(String message) {
        super(message);
    }


    public OWLXMLOntologyStorageException(String message, Throwable cause) {
        super(message, cause);
    }


    public OWLXMLOntologyStorageException(Throwable cause) {
        super(cause);
    }
}

==> owlapi-parsers-3.5.0-sources.jar: org/coode/owlapi/owlxml/renderer/OWLXMLOntologyStorageException.java <==
/*
 * This file is part of the OWL API.
 *
 * The contents of this file are subject to the LGPL License, Version 3.0.
 *
 * Copyright (C) 2011, The University of Manchester
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0
 * in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 *
 * Copyright 2011, University of Manchester
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.coode.owlapi.owlxml.renderer;

import org.semanticweb.owlapi.model.OWLOntologyStorageException;

/**
 * The Class OWLXMLOntologyStorageException.
 * 
 * @author Matthew Horridge, The University Of Manchester, Bio-Health
 *         Informatics Group, Date: 13-Apr-2007
 */
public class OWLXMLOntologyStorageException extends OWLOntologyStorageException {

    /** The Constant serialVersionUID. */
    private static final long serialVersionUID = 30406L;

    /**
     * Instantiates a new oWLXML ontology storage exception.
     * 
     * @param message
     *        the message
     */
    public OWLXMLOntologyStorageException(String message) {
        super(message);
    }

    /**
     * Instantiates a new oWLXML ontology storage exception.
     * 
     * @param message
     *        the message
     * @param cause
     *        the cause
     */
    public OWLXMLOntologyStorageException(String message, Throwable cause) {
        super(message, cause);
    }

    /**
     * Instantiates a new oWLXML ontology storage exception.
     * 
     * @param cause
     *        the cause
     */
    public OWLXMLOntologyStorageException(Throwable cause) {
        super(cause);
    }
}
